
# Slot: gene associated with condition


holds between a gene and a disease or phenotypic feature that the gene or its alleles/products may influence, contribute to, or correlate with

URI: [biolink:gene_associated_with_condition](https://w3id.org/biolink/vocab/gene_associated_with_condition)


## Domain and Range

[Gene](Gene.md) &#8594;  <sub>0..\*</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [genetic association](genetic_association.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RTXKG1:gene_associated_with_condition |
| **Narrow Mappings:** | | NCIT:R38 |
|  | | NCIT:R175 |
|  | | NCIT:R48 |
| **Broad Mappings:** | | GENO:0000840 |
|  | | GENO:0000841 |

